/*
** TextLayout_h
**
** Copyright 1992 by Markku Savela and
**	Technical Research Centre of Finland
*/
#ifndef TextLayout_h
#define TextLayout_h

#include <X11/Xew/TextP.h>


_XFUNCPROTOBEGIN
int _XeTextLayout(
#if NeedFunctionPrototypes
		 XeTextWidget, XeTextLayoutGeometry *, Snip *, Region
#endif
);
int XeTextSnipWidth
	(
#if NeedFunctionPrototypes
	 XeTextWidget, Snip *, char *, int
#endif
	 );

_XFUNCPROTOEND
#endif

